from setuptools import find_packages, setup

setup(
    name="eriparse",
    version="0.0.1",
    description="HTML parsing logic for `https://www.erieri.com/cost-of-living-calculator`.",
    packages=find_packages(),
)
